@@ -218,7 +218,10 @@ class Api:
                         frag = prop.split("=")
                         # TODO - remove
                         print(frag)
-                        obj[frag[0]] = frag[1].replace("\"", " ").strip()
+                        try:
+                            obj[frag[0]] = frag[1].replace("\"", " ").strip()
+                        except IndexError:
+                            continue
 
                     # TODO - remove
                     # obj[INELS_BUS_ATTR_DICT.get(ATTR_TYPE)] = DEVICE_TYPE_DICT.get(d_type)
